ATTEffBounds: Efficiency bounds for confidence intervals

Description Usage Arguments Value References Examples

View source: R/att_estimate.R

Description

Computes the asymptotic efficiency of two-sided fixed-length confidence intervals at smooth functions, as well as the efficiency of one-sided confidence intervals that optimize a given beta quantile of excess length, using the formula described in Appendix A of Armstrong and Kolesár (2020)

Usage

1
ATTEffBounds(path, C = 1, beta = 0.8, alpha = 0.05, sigma2, J = 3, DM)

Arguments

path

The output of ATTOptPath.

C

Lipschitz smoothness constant

beta

quantile beta of excess length for determining performance of one-sided CIs.

alpha

determines confidence level, 1-alpha.

sigma2

estimate of the conditional variance of the outcome (assuming homoskedasticity). If not supplied, use homoskedastic variance estimate based on a nearest neighbor variance estimator.

J

number of nearest neighbors to use when estimating sigma2.

DM

distance matrix with dimension n by n to determine nearest neighbors when when estimating sigma2.

Value

A list with two elements, onesided and twosided, for one- and two-sided efficiency.

References

Armstrong, T. B., and M. Kolesár (2020): Finite-Sample Optimal Estimation and Inference on Average Treatment Effects Under Unconfoundedness, https://arxiv.org/abs/1712.04594

Examples

1
2
3
4
5
6
7
8
9
## Use NSW experimental subsample with 25 treated and untreated units
dt <- NSWexper[c(1:25, 421:445), ]
Ahalf <- diag(c(0.15, 0.6, 2.5, 2.5, 2.5, 0.5, 0.5, 0.1, 0.1))
D0 <- distMat(dt[, 2:10], Ahalf, method="manhattan", dt$treated)
## Distance matrix for variance estimation
DM <- distMat(dt[, 2:10], Ahalf, method="manhattan")
## Compute the solution path, first 50 steps will be sufficient
path <- ATTOptPath(dt$re78, dt$treated, D0, maxsteps=50)
ATTEffBounds(path, C=1, DM=DM)

kolesarm/ATEHonest documentation built on Nov. 14, 2020, 4:50 a.m.