Description Usage Arguments Value Examples
Compute a matrix of distances between n observations using the
distance measure in method.
1 |
X |
Design matrix of covariates with dimension |
Ahalf |
Weight matrix with dimension |
method |
the distance measure to be used. This must be one of
|
d |
Vector of treatment indicators with length |
p |
The power of the Minkowski distance. |
Matrix of distances with dimension n by n or else
n1 by n0
1 2 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.