Description Usage Arguments Value References Examples
Computes the asymptotic efficiency of two-sided fixed-length confidence
intervals at smooth functions, as well as the efficiency of one-sided
confidence intervals that optimize a given beta quantile of excess
length, using the formula described in Appendix A of Armstrong and Kolesár
(2020)
1 | ATTEffBounds(path, C = 1, beta = 0.8, alpha = 0.05, sigma2, J = 3, DM)
|
path |
The output of |
C |
Lipschitz smoothness constant |
beta |
quantile |
alpha |
determines confidence level, |
sigma2 |
estimate of the conditional variance of the outcome (assuming homoskedasticity). If not supplied, use homoskedastic variance estimate based on a nearest neighbor variance estimator. |
J |
number of nearest neighbors to use when estimating |
DM |
distance matrix with dimension |
A list with two elements, onesided and twosided, for
one- and two-sided efficiency.
Armstrong, T. B., and M. Kolesár (2020): Finite-Sample Optimal Estimation and Inference on Average Treatment Effects Under Unconfoundedness, https://arxiv.org/abs/1712.04594
1 2 3 4 5 6 7 8 9 | ## Use NSW experimental subsample with 25 treated and untreated units
dt <- NSWexper[c(1:25, 421:445), ]
Ahalf <- diag(c(0.15, 0.6, 2.5, 2.5, 2.5, 0.5, 0.5, 0.1, 0.1))
D0 <- distMat(dt[, 2:10], Ahalf, method="manhattan", dt$treated)
## Distance matrix for variance estimation
DM <- distMat(dt[, 2:10], Ahalf, method="manhattan")
## Compute the solution path, first 50 steps will be sufficient
path <- ATTOptPath(dt$re78, dt$treated, D0, maxsteps=50)
ATTEffBounds(path, C=1, DM=DM)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.